searchNodes=[{"ref":"EctoEnumerize.html","title":"EctoEnumerize","module":"EctoEnumerize","type":"module","doc":"Provides EctoEnumerize.defenum/2 macro for defining an Enum Ecto type."},{"ref":"EctoEnumerize.html#defenum/2","title":"EctoEnumerize.defenum/2","module":"EctoEnumerize","type":"macro","doc":"Defines a custom Enum Ecto.Type."},{"ref":"readme.html","title":"EctoEnumerize","module":"readme","type":"extras","doc":"EctoEnumerize EctoEnumerize allows to define custom enums (keyword lists) to be used in your Ecto schemes."},{"ref":"readme.html#why","title":"EctoEnumerize - Why?","module":"readme","type":"extras","doc":"It differs from EctoEnum because EctoEnumerize does not use the PostgreSQL native Enum type, instead it stores the value as an integer and therefore it should work on any database. While it&#39;s easy to add new values to your Enum when using PostgreSQL native Enum type, it appears there is no easy solution to remove them without having to drop and create the enum again. Check this thread on stackoverflow for more info. It does not affect this library since the Enum is handled at the application level."},{"ref":"readme.html#usage","title":"EctoEnumerize - Usage","module":"readme","type":"extras","doc":"First, we add ecto_enumerize to mix.exs: def deps do [ {:ecto_enumerize, &quot;~&gt; 0.1.1&quot;} ] end Run mix deps.get to install ecto_enumerize. Now we can define our enum as follow: defmodule Order do use Ecto.Schema import EctoEnumerize defenum Status, pending: 0, shipped: 1, delivered: 2 schema &quot;orders&quot; do field :status, Status, default: :pending end def changeset(order, attrs) do cast(order, attrs, [:status]) end end In the above example, the :status will behave like an enum and will allow you to pass an integer, atom or string to it. This applies to saving the model, invoking Ecto.Changeset.cast/4, or performing a query on the status field. Some examples: iex&gt; Order.Status.get_enum() [pending: 0, shipped: 1, delivered: 2] iex&gt; order = Repo.insert!(%Order{status: :delivered}) iex&gt; Repo.get(Order, order.id).status :delivered iex&gt; # any of these values will produce the same result iex&gt; s = Enum.random([:delivered, &quot;delivered&quot;, 2]) iex&gt; from(o in Order, where: o.status == ^s) |&gt; Repo.aggregate(:count, :id) 1 Passing an invalid value to a Ecto.Changeset.cast/3 will add an error to changeset.errors field. iex&gt; cs = Order.changeset(order, %{status: :unknown}) iex&gt; cs.errors [status: {&quot;is invalid&quot;, [type: Order.Status, validation: :cast]}] Migrations Simple as that: def change do create table(:orders) do add :status, :integer end end"},{"ref":"readme.html#important-links","title":"EctoEnumerize - Important links","module":"readme","type":"extras","doc":"Documentation License"}]